Trait typenum::type_operators::Min
[−]
[src]
pub trait Min<Rhs = Self> {
type Output;
fn min(self, rhs: Rhs) -> Self::Output;
}A type operator that returns the minimum of Self and Rhs.
Associated Types
type Output
The type of the minimum of Self and Rhs
Required Methods
Implementors
impl Min<B0> for B0impl Min<B1> for B0impl Min<B0> for B1impl Min<B1> for B1impl<U> Min<U> for UTerm where U: Unsignedimpl<U, B, Ur> Min<Ur> for UInt<U, B> where U: Unsigned,
B: Bit,
Ur: Unsigned,
UInt<U, B>: Cmp<Ur> + PrivateMin<Ur, Compare<UInt<U, B>, Ur>>impl Min<Z0> for Z0impl<U> Min<PInt<U>> for Z0 where U: Unsigned + NonZeroimpl<U> Min<NInt<U>> for Z0 where U: Unsigned + NonZeroimpl<U> Min<Z0> for PInt<U> where U: Unsigned + NonZeroimpl<U> Min<Z0> for NInt<U> where U: Unsigned + NonZeroimpl<Ul, Ur> Min<PInt<Ur>> for PInt<Ul> where Ul: Unsigned + NonZero + Min<Ur>,
Ur: Unsigned + NonZero,
Minimum<Ul, Ur>: Unsigned + NonZeroimpl<Ul, Ur> Min<PInt<Ur>> for NInt<Ul> where Ul: Unsigned + NonZero,
Ur: Unsigned + NonZeroimpl<Ul, Ur> Min<NInt<Ur>> for PInt<Ul> where Ul: Unsigned + NonZero,
Ur: Unsigned + NonZeroimpl<Ul, Ur> Min<NInt<Ur>> for NInt<Ul> where Ul: Unsigned + NonZero + Max<Ur>,
Ur: Unsigned + NonZero,
Maximum<Ul, Ur>: Unsigned + NonZero